.editorconfig
.env
.env.example
.gitattributes
.gitignore
AGENTS.md
CLAUDE.md
CODE_OF_CONDUCT.md
CONTRIBUTING.md
LICENSE
README.md
SECURITY.md
UPGRADE.md
app
artisan
bootstrap
composer.json
composer.lock
config
database
docker
docker-compose.yml
lang
package.json
packages
phpunit.xml
pint.json
public
resources
routes
storage
tests
vendor
vite.config.js
.htaccess